ete2.treeview._search_dialog

Package ete2 :: Package treeview :: Module _search_dialog |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.treeview._search_dialog

     1  # #START_LICENSE###########################################################
     2  #
     3  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     4  # email: jhcepas@gmail.com
     5  #
     6  # This file is part of the Environment for Tree Exploration program (ETE).
     7  # http://ete.cgenomics.org
     8  #
     9  # ETE is free software: you can redistribute it and/or modify it
    10  # under the terms of the GNU General Public License as published by
    11  # the Free Software Foundation, either version 3 of the License, or
    12  # (at your option) any later version.
    13  #
    14  # ETE is distributed in the hope that it will be useful,
    15  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    16  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    17  # GNU General Public License for more details.
    18  #
    19  # You should have received a copy of the GNU General Public License
    20  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    21  #
    22  # #END_LICENSE#############################################################
    23  __VERSION__="ete2-2.0rev90"
    24  # -*- coding: utf-8 -*-
    25
    26  # Form implementation generated from reading ui file 'search_dialog.ui'
    27  #
    28  # Created: Mon Sep 14 11:11:49 2009
    29  #      by: PyQt4 UI code generator 4.5.4
    30  #
    31  # WARNING! All changes made in this file will be lost!
    32
    33  try:
    34      from PyQt4 import QtCore, QtGui
    35  except ImportError:
    36      import QtCore, QtGui
    37
    38
    39 -class Ui_Dialog(object):
    40 -    def setupUi(self, Dialog):
    41          Dialog.setObjectName("Dialog")
    42          Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
    43          Dialog.resize(424, 160)
    44          self.buttonBox = QtGui.QDialogButtonBox(Dialog)
    45          self.buttonBox.setGeometry(QtCore.QRect(140, 120, 171, 32))
    46          self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
    47          self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
    48          self.buttonBox.setCenterButtons(True)
    49          self.buttonBox.setObjectName("buttonBox")
    50          self.leaves_only = QtGui.QCheckBox(Dialog)
    51          self.leaves_only.setWindowModality(QtCore.Qt.NonModal)
    52          self.leaves_only.setGeometry(QtCore.QRect(30, 80, 181, 24))
    53          self.leaves_only.setObjectName("leaves_only")
    54          self.attrType = QtGui.QComboBox(Dialog)
    55          self.attrType.setGeometry(QtCore.QRect(80, 40, 181, 23))
    56          self.attrType.setObjectName("attrType")
    57          self.attrType.addItem(QtCore.QString())
    58          self.attrType.addItem(QtCore.QString())
    59          self.attrType.addItem(QtCore.QString())
    60          self.attrType.addItem(QtCore.QString())
    61          self.attrType.addItem(QtCore.QString())
    62          self.attrType.addItem(QtCore.QString())
    63          self.attrType.addItem(QtCore.QString())
    64          self.attrType.addItem(QtCore.QString())
    65          self.label = QtGui.QLabel(Dialog)
    66          self.label.setGeometry(QtCore.QRect(10, 10, 181, 20))
    67          self.label.setObjectName("label")
    68          self.attrName = QtGui.QLineEdit(Dialog)
    69          self.attrName.setGeometry(QtCore.QRect(270, 10, 113, 25))
    70          self.attrName.setObjectName("attrName")
    71          self.attrValue = QtGui.QLineEdit(Dialog)
    72          self.attrValue.setGeometry(QtCore.QRect(270, 40, 113, 25))
    73          self.attrValue.setObjectName("attrValue")
    74
    75          self.retranslateUi(Dialog)
    76          QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), Dialog.accept)
    77          QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), Dialog.reject)
    78          QtCore.QMetaObject.connectSlotsByName(Dialog)
    79          Dialog.setTabOrder(self.attrName, self.attrType)
    80          Dialog.setTabOrder(self.attrType, self.attrValue)
    81          Dialog.setTabOrder(self.attrValue, self.leaves_only)
    82          Dialog.setTabOrder(self.leaves_only, self.buttonBox)
    83
    84 -    def retranslateUi(self, Dialog):
    85          Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
    86          self.leaves_only.setText(QtGui.QApplication.translate("Dialog", "Search only for leaf nodes", None, QtGui.QApplication.UnicodeUTF8))
    87          self.attrType.setItemText(0, QtGui.QApplication.translate("Dialog", "is", None, QtGui.QApplication.UnicodeUTF8))
    88          self.attrType.setItemText(1, QtGui.QApplication.translate("Dialog", "contains", None, QtGui.QApplication.UnicodeUTF8))
    89          self.attrType.setItemText(2, QtGui.QApplication.translate("Dialog", "== ", None, QtGui.QApplication.UnicodeUTF8))
    90          self.attrType.setItemText(3, QtGui.QApplication.translate("Dialog", ">=", None, QtGui.QApplication.UnicodeUTF8))
    91          self.attrType.setItemText(4, QtGui.QApplication.translate("Dialog", ">", None, QtGui.QApplication.UnicodeUTF8))
    92          self.attrType.setItemText(5, QtGui.QApplication.translate("Dialog", "<=", None, QtGui.QApplication.UnicodeUTF8))
    93          self.attrType.setItemText(6, QtGui.QApplication.translate("Dialog", "<", None, QtGui.QApplication.UnicodeUTF8))
    94          self.attrType.setItemText(7, QtGui.QApplication.translate("Dialog", "matches this regular expression", None, QtGui.QApplication.UnicodeUTF8))
    95          self.label.setText(QtGui.QApplication.translate("Dialog", "Search nodes with attribute", None, QtGui.QApplication.UnicodeUTF8))
    96          self.attrName.setText(QtGui.QApplication.translate("Dialog", "name", None, QtGui.QApplication.UnicodeUTF8))
    97